@@ -758,14 +758,14 @@ class Md5Checkvalue(MtimeCheckvalue):
 
 
 class GitCheckvalue(object):
-    def __init__(self, rpath):
+    def __init__(self, git, rpath):
         self.rpath = rpath
-        self.git = Git()
+        self.git = git
 
     def checkvalues(self):
         with ignore(GitError):
             if self.git.is_git(self.rpath):
-                yield self.rpath, Git().getCurrentCommit(self.rpath)
+                yield self.rpath, self.git.getCurrentCommit(self.rpath)
 
 
 class EmergeCache(object):
