@@ -120,6 +120,9 @@ class ClUpdateProfileAction(Action):
               'message': __("Switching to profile {cl_update_profile_system}"),
               'method': 'Update.setProfile(cl_update_profile_system)'
               },
+             {'name': 'rename_custom',
+              'method': 'Update.rename_custom_files()',
+             },
              {'name': 'revision',
               'message': __("Fixing the settings"),
               'method': 'Update.applyProfileTemplates(cl_template_clt_set,'
