@@ -1434,9 +1434,9 @@ class VariableClUpdateKernelPkg(ReadonlyVariable):
     def get(self):
         src_path = self.Get('cl_update_kernel_src_path')
         if src_path:
-            qfile = process('/usr/bin/qfile', '-vC', src_path)
+            qfile = process('/usr/bin/qfile', '-vqC', src_path)
             if qfile.success():
-                return qfile.read().partition(" ")[0]
+                return qfile.read()
         return ""
 
 
